@@ -47,17 +47,30 @@ import config
 from dicttreeview import DictionaryTreeView
 from shortcuteditor import ShortcutEditor
 
+DOMAINNAME = 'ibus-libpinyin'
 locale.setlocale(locale.LC_ALL, "")
 localedir = os.getenv("IBUS_LOCALEDIR")
 pkgdatadir = os.getenv("IBUS_PKGDATADIR") or "."
-gettext.install('ibus-libpinyin', localedir)
+
+# Python's locale module doesn't provide all methods on some
+# operating systems like FreeBSD
+try:
+    locale.bindtextdomain(DOMAINNAME, localedir)
+    locale.bind_textdomain_codeset(DOMAINNAME, 'UTF-8')
+except AttributeError:
+    pass
+
+gettext.bindtextdomain(DOMAINNAME, localedir)
+gettext.bind_textdomain_codeset(DOMAINNAME, 'UTF-8')
+
+gettext.install(DOMAINNAME, localedir)
 
 class PreferencesDialog:
     def __init__(self, engine):
         self.__bus = IBus.Bus()
         self.__config = self.__bus.get_config()
         self.__builder = Gtk.Builder()
-        self.__builder.set_translation_domain("ibus-libpinyin")
+        self.__builder.set_translation_domain(DOMAINNAME)
         self.__builder.add_from_file("ibus-libpinyin-preferences.ui")
         self.__dialog = self.__builder.get_object("dialog")
         self.__init_pages()
@@ -131,29 +144,29 @@ class PreferencesDialog:
         self.__remember_every_input = self.__builder.get_object("RememberEveryInput")
 
         # read values
-        self.__init_chinese.set_active(self.__get_value("initchinese", True))
-        self.__init_full.set_active(self.__get_value("initfull", False))
-        self.__init_full_punct.set_active(self.__get_value("initfullpunct", True))
-        self.__init_simp.set_active(self.__get_value("initsimplifiedchinese", True))
+        self.__init_chinese.set_active(self.__get_value("init-chinese", True))
+        self.__init_full.set_active(self.__get_value("init-full", False))
+        self.__init_full_punct.set_active(self.__get_value("init-full-punct", True))
+        self.__init_simp.set_active(self.__get_value("init-simplified-chinese", True))
 
-        self.__lookup_table_orientation.set_active(self.__get_value("lookuptableorientation", 0))
-        self.__lookup_table_page_size.set_value(self.__get_value("lookuptablepagesize", 5))
+        self.__lookup_table_orientation.set_active(self.__get_value("lookup-table-orientation", 0))
+        self.__lookup_table_page_size.set_value(self.__get_value("lookup-table-page-size", 5))
 
-        self.__dynamic_adjust.set_active(self.__get_value("dynamicadjust", True))
-        self.__remember_every_input.set_active(self.__get_value("remembereveryinput", False))
+        self.__dynamic_adjust.set_active(self.__get_value("dynamic-adjust", True))
+        self.__remember_every_input.set_active(self.__get_value("remember-every-input", False))
         # connect signals
-        self.__init_chinese.connect("toggled", self.__toggled_cb, "initchinese")
-        self.__init_full.connect("toggled", self.__toggled_cb, "initfull")
-        self.__init_full_punct.connect("toggled", self.__toggled_cb, "initfullpunct")
-        self.__init_simp.connect("toggled", self.__toggled_cb, "initsimplifiedchinese")
-        self.__dynamic_adjust.connect("toggled", self.__toggled_cb, "dynamicadjust")
-        self.__remember_every_input.connect("toggled", self.__toggled_cb, "remembereveryinput")
+        self.__init_chinese.connect("toggled", self.__toggled_cb, "init-chinese")
+        self.__init_full.connect("toggled", self.__toggled_cb, "init-full")
+        self.__init_full_punct.connect("toggled", self.__toggled_cb, "init-full-punct")
+        self.__init_simp.connect("toggled", self.__toggled_cb, "init-simplified-chinese")
+        self.__dynamic_adjust.connect("toggled", self.__toggled_cb, "dynamic-adjust")
+        self.__remember_every_input.connect("toggled", self.__toggled_cb, "remember-every-input")
 
         def __lookup_table_page_size_changed_cb(adjustment):
-            self.__set_value("lookuptablepagesize", int(adjustment.get_value()))
+            self.__set_value("lookup-table-page-size", int(adjustment.get_value()))
 
         def __lookup_table_orientation_changed_cb(widget):
-            self.__set_value("lookuptableorientation", widget.get_active())
+            self.__set_value("lookup-table-orientation", widget.get_active())
 
         self.__lookup_table_orientation.connect("changed", __lookup_table_orientation_changed_cb)
         self.__lookup_table_page_size.connect("value-changed", __lookup_table_page_size_changed_cb)
@@ -172,9 +185,9 @@ class PreferencesDialog:
         self.__double_pinyin_show_raw.hide ()
 
         # read value
-        self.__incomplete_pinyin.set_active(self.__get_value("incompletepinyin", True))
-        self.__full_pinyin.set_active(not self.__get_value("doublepinyin", False))
-        self.__double_pinyin_schema.set_active(self.__get_value("doublepinyinschema", 0))
+        self.__incomplete_pinyin.set_active(self.__get_value("incomplete-pinyin", True))
+        self.__full_pinyin.set_active(not self.__get_value("double-pinyin", False))
+        self.__double_pinyin_schema.set_active(self.__get_value("double-pinyin-schema", 0))
         if self.__full_pinyin.get_active():
             # self.__incomplete_pinyin.set_sensitive(True)
             self.__double_pinyin_schema.set_sensitive(False)
@@ -188,19 +201,19 @@ class PreferencesDialog:
 
         def __double_pinyin_toggled_cb(widget):
             val = widget.get_active()
-            self.__set_value("doublepinyin", val)
+            self.__set_value("double-pinyin", val)
             self.__double_pinyin_schema.set_sensitive(val)
             # self.__double_pinyin_schema_label.set_sensitive(val)
             self.__double_pinyin_show_raw.set_sensitive(val)
 
         def __double_pinyin_schema_changed_cb(widget):
-            self.__set_value("doublepinyinschema", widget.get_active())
+            self.__set_value("double-pinyin-schema", widget.get_active())
 
         # connect signals
         self.__double_pinyin.connect("toggled", __double_pinyin_toggled_cb)
-        self.__incomplete_pinyin.connect("toggled", self.__toggled_cb, "incompletepinyin")
+        self.__incomplete_pinyin.connect("toggled", self.__toggled_cb, "incomplete-pinyin")
         self.__double_pinyin_schema.connect("changed", __double_pinyin_schema_changed_cb)
-        self.__double_pinyin_show_raw.connect("toggled", self.__toggled_cb, "doublepinyinshowraw")
+        self.__double_pinyin_show_raw.connect("toggled", self.__toggled_cb, "double-pinyin-show-raw")
 
         self.__init_input_custom()
         self.__init_correct_pinyin()
@@ -223,27 +236,27 @@ class PreferencesDialog:
         self.__enter_key = self.__builder.get_object("CommitFirstCandidate")
 
         # read value
-        self.__bopomofo_keyboard_mapping.set_active(self.__get_value("bopomofokeyboardmapping", 0))
-        self.__incomplete_bopomofo.set_active(self.__get_value("incompletepinyin", False))
-        self.__select_keys.set_active(self.__get_value("selectkeys", 0))
-        self.__guide_key.set_active(self.__get_value("guidekey", 1))
-        self.__auxiliary_select_key_f.set_active(self.__get_value("auxiliaryselectkey_f", 1))
-        self.__auxiliary_select_key_kp.set_active(self.__get_value("auxiliaryselectkey_kp", 1))
-        self.__enter_key.set_active(self.__get_value("enterkey", True))
+        self.__bopomofo_keyboard_mapping.set_active(self.__get_value("bopomofo-keyboard-mapping", 0))
+        self.__incomplete_bopomofo.set_active(self.__get_value("incomplete-pinyin", False))
+        self.__select_keys.set_active(self.__get_value("select-keys", 0))
+        self.__guide_key.set_active(self.__get_value("guide-key", 1))
+        self.__auxiliary_select_key_f.set_active(self.__get_value("auxiliary-select-key-f", 1))
+        self.__auxiliary_select_key_kp.set_active(self.__get_value("auxiliary-select-key-kp", 1))
+        self.__enter_key.set_active(self.__get_value("enter-key", True))
 
         # connect signals
         def __bopomofo_keyboard_mapping_changed_cb(widget):
-            self.__set_value("bopomofokeyboardmapping", widget.get_active())
+            self.__set_value("bopomofo-keyboard-mapping", widget.get_active())
         def __select_keys_changed_cb(widget):
-            self.__set_value("selectkeys", widget.get_active())
+            self.__set_value("select-keys", widget.get_active())
 
         self.__bopomofo_keyboard_mapping.connect("changed", __bopomofo_keyboard_mapping_changed_cb)
-        self.__incomplete_bopomofo.connect("toggled", self.__toggled_cb, "incompletepinyin")
+        self.__incomplete_bopomofo.connect("toggled", self.__toggled_cb, "incomplete-pinyin")
         self.__select_keys.connect("changed", __select_keys_changed_cb)
-        self.__guide_key.connect("toggled", self.__toggled_cb, "guidekey")
-        self.__auxiliary_select_key_f.connect("toggled", self.__toggled_cb, "auxiliaryselectkey_f")
-        self.__auxiliary_select_key_kp.connect("toggled", self.__toggled_cb, "auxiliaryselectkey_kp")
-        self.__enter_key.connect("toggled", self.__toggled_cb, "enterkey")
+        self.__guide_key.connect("toggled", self.__toggled_cb, "guide-key")
+        self.__auxiliary_select_key_f.connect("toggled", self.__toggled_cb, "auxiliary-select-key-f")
+        self.__auxiliary_select_key_kp.connect("toggled", self.__toggled_cb, "auxiliary-select-key-kp")
+        self.__enter_key.connect("toggled", self.__toggled_cb, "enter-key")
 
     def __init_input_custom(self):
         # others
@@ -253,29 +266,29 @@ class PreferencesDialog:
         self.__auto_commit = self.__builder.get_object("AutoCommit")
 
         # read values
-        self.__shift_select_candidate.set_active(self.__get_value("shiftselectcandidate", False))
-        self.__minus_equal_page.set_active(self.__get_value("minusequalpage", True))
-        self.__comma_period_page.set_active(self.__get_value("commaperiodpage", True))
-        self.__auto_commit.set_active(self.__get_value("autocommit", False))
+        self.__shift_select_candidate.set_active(self.__get_value("shift-select-candidate", False))
+        self.__minus_equal_page.set_active(self.__get_value("minus-equal-page", True))
+        self.__comma_period_page.set_active(self.__get_value("comma-period-page", True))
+        self.__auto_commit.set_active(self.__get_value("auto-commit", False))
 
         # connect signals
-        self.__shift_select_candidate.connect("toggled", self.__toggled_cb, "shiftselectcandidate")
-        self.__minus_equal_page.connect("toggled", self.__toggled_cb, "minusequalpage")
-        self.__comma_period_page.connect("toggled", self.__toggled_cb, "commaperiodpage")
-        self.__auto_commit.connect("toggled", self.__toggled_cb, "autocommit")
+        self.__shift_select_candidate.connect("toggled", self.__toggled_cb, "shift-select-candidate")
+        self.__minus_equal_page.connect("toggled", self.__toggled_cb, "minus-equal-page")
+        self.__comma_period_page.connect("toggled", self.__toggled_cb, "comma-period-page")
+        self.__auto_commit.connect("toggled", self.__toggled_cb, "auto-commit")
 
     def __init_correct_pinyin(self):
         # auto correct
         self.__correct_pinyin = self.__builder.get_object("CorrectPinyin")
         self.__correct_pinyin_widgets = [
-            ("CorrectPinyin_GN_NG", True),
-            ("CorrectPinyin_MG_NG", True),
-            ("CorrectPinyin_IOU_IU", True),
-            ("CorrectPinyin_UEI_UI", True),
-            ("CorrectPinyin_UEN_UN", True),
-            ("CorrectPinyin_UE_VE", True),
-            ("CorrectPinyin_V_U", True),
-            ("CorrectPinyin_ON_ONG", True),
+            ('CorrectPinyin_GN_NG', 'correct-pinyin-gn-ng', True),
+            ('CorrectPinyin_MG_NG', 'correct-pinyin-mg-ng', True),
+            ('CorrectPinyin_IOU_IU', 'correct-pinyin-iou-iu', True),
+            ('CorrectPinyin_UEI_UI', 'correct-pinyin-uei-ui', True),
+            ('CorrectPinyin_UEN_UN', 'correct-pinyin-uen-un', True),
+            ('CorrectPinyin_UE_VE', 'correct-pinyin-ue-ve', True),
+            ('CorrectPinyin_V_U', 'correct-pinyin-v-u', True),
+            ('CorrectPinyin_ON_ONG', 'correct-pinyin-on-ong', True),
         ]
 
         def __correct_pinyin_toggled_cb(widget):
@@ -285,15 +298,15 @@ class PreferencesDialog:
         self.__correct_pinyin.connect("toggled", __correct_pinyin_toggled_cb)
 
         # init value
-        self.__correct_pinyin.set_active(self.__get_value("correctpinyin", True))
-        for name, defval in self.__correct_pinyin_widgets:
+        self.__correct_pinyin.set_active(self.__get_value("correct-pinyin", True))
+        for name, keyname, defval in self.__correct_pinyin_widgets:
             widget = self.__builder.get_object(name)
-            widget.set_active(self.__get_value(name.lower(), defval))
+            widget.set_active(self.__get_value(keyname, defval))
 
-        self.__correct_pinyin.connect("toggled", self.__toggled_cb, "correctpinyin")
-        for name, defval in self.__correct_pinyin_widgets:
+        self.__correct_pinyin.connect("toggled", self.__toggled_cb, "correct-pinyin")
+        for name, keyname, defval in self.__correct_pinyin_widgets:
             widget = self.__builder.get_object(name)
-            widget.connect("toggled", self.__toggled_cb, name.lower())
+            widget.connect("toggled", self.__toggled_cb, keyname)
 
     def __init_fuzzy(self):
         # page Fuzzy
@@ -302,16 +315,16 @@ class PreferencesDialog:
         # fuzzy pinyin
         self.__fuzzy_pinyin = self.__builder.get_object("FuzzyPinyin")
         self.__fuzzy_pinyin_widgets = [
-            ("FuzzyPinyin_C_CH", True),
-            ("FuzzyPinyin_Z_ZH", True),
-            ("FuzzyPinyin_S_SH", True),
-            ("FuzzyPinyin_L_N", True),
-            ("FuzzyPinyin_F_H", True),
-            ("FuzzyPinyin_L_R", False),
-            ("FuzzyPinyin_G_K", False),
-            ("FuzzyPinyin_AN_ANG", True),
-            ("FuzzyPinyin_EN_ENG", True),
-            ("FuzzyPinyin_IN_ING", True),
+            ('FuzzyPinyin_C_CH', 'fuzzy-pinyin-c-ch', True),
+            ('FuzzyPinyin_Z_ZH', 'fuzzy-pinyin-z-zh', True),
+            ('FuzzyPinyin_S_SH', 'fuzzy-pinyin-s-sh', True),
+            ('FuzzyPinyin_L_N', 'fuzzy-pinyin-l-n', True),
+            ('FuzzyPinyin_F_H', 'fuzzy-pinyin-f-h', True),
+            ('FuzzyPinyin_L_R', 'fuzzy-pinyin-l-r', False),
+            ('FuzzyPinyin_G_K', 'fuzzy-pinyin-g-k', False),
+            ('FuzzyPinyin_AN_ANG', 'fuzzy-pinyin-an-ang', True),
+            ('FuzzyPinyin_EN_ENG', 'fuzzy-pinyin-en-eng', True),
+            ('FuzzyPinyin_IN_ING', 'fuzzy-pinyin-in-ing', True),
         ]
 
         def __fuzzy_pinyin_toggled_cb(widget):
@@ -321,15 +334,15 @@ class PreferencesDialog:
         self.__fuzzy_pinyin.connect("toggled", __fuzzy_pinyin_toggled_cb)
 
         # init value
-        self.__fuzzy_pinyin.set_active(self.__get_value("fuzzypinyin", False))
-        for name, defval in self.__fuzzy_pinyin_widgets:
+        self.__fuzzy_pinyin.set_active(self.__get_value("fuzzy-pinyin", False))
+        for name, keyname, defval in self.__fuzzy_pinyin_widgets:
             widget = self.__builder.get_object(name)
-            widget.set_active(self.__get_value(name.lower(), defval))
+            widget.set_active(self.__get_value(keyname, defval))
 
-        self.__fuzzy_pinyin.connect("toggled", self.__toggled_cb, "fuzzypinyin")
-        for name, defval in self.__fuzzy_pinyin_widgets:
+        self.__fuzzy_pinyin.connect("toggled", self.__toggled_cb, "fuzzy-pinyin")
+        for name, keyname, defval in self.__fuzzy_pinyin_widgets:
             widget = self.__builder.get_object(name)
-            widget.connect("toggled", self.__toggled_cb, name.lower())
+            widget.connect("toggled", self.__toggled_cb, keyname)
 
     def __convert_fuzzy_pinyin_to_bopomofo(self):
         options = [
@@ -356,7 +369,7 @@ class PreferencesDialog:
         # dictionary tree view
         self.__dict_treeview = self.__builder.get_object("Dictionaries")
         self.__dict_treeview.show()
-        self.__dict_treeview.set_dictionaries(self.__get_value("dictionaries", "2"))
+        self.__dict_treeview.set_dictionaries(self.__get_value("dictionaries", ""))
 
         def __notified_dicts_cb(self, param, dialog):
             dialog.__set_value("dictionaries", self.get_dictionaries())
@@ -411,7 +424,7 @@ class PreferencesDialog:
 
         response = dialog.run()
         if response == Gtk.ResponseType.OK:
-            self.__set_value("importdictionary", dialog.get_filename())
+            self.__set_value("import-dictionary", dialog.get_filename())
 
         dialog.destroy()
 
@@ -430,12 +443,12 @@ class PreferencesDialog:
 
         response = dialog.run()
         if response == Gtk.ResponseType.OK:
-            self.__set_value("exportdictionary", dialog.get_filename())
+            self.__set_value("export-dictionary", dialog.get_filename())
 
         dialog.destroy()
 
     def __clear_user_data_cb(self, widget, name):
-        self.__set_value("clearuserdata", name)
+        self.__set_value("clear-user-data", name)
 
     def __init_shortcut(self):
         # page Shortcut
